@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2009, 2010, 2011, 2012 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2009, 2010, 2011, 2012, 2013, 2014 Graeme Gott <graeme@gottcode.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,133 +28,29 @@
 #include "scene_model.h"
 #include "smart_quotes.h"
 #include "symbols_dialog.h"
-#include "theme.h"
+#include "theme_renderer.h"
 
 #include <QAction>
 #include <QApplication>
 #include <QClipboard>
-#include <QFileInfo>
+#include <QDir>
 #include <QGridLayout>
+#include <QMenu>
 #include <QMessageBox>
-#include <QMutex>
-#include <QMutexLocker>
 #include <QPainter>
 #include <QPaintEvent>
-#include <QPlainTextEdit>
 #include <QStackedWidget>
 #include <QTextBlock>
-#include <QTextCodec>
 #include <QTextCursor>
-#include <QTextStream>
-#include <QThread>
+#include <QTextEdit>
 #include <QTimer>
 
 //-----------------------------------------------------------------------------
 
-namespace
-{
-	class BackgroundLoader : public QThread
-	{
-	public:
-		void create(int position, const QString& image_path, QWidget* widget);
-		QPixmap pixmap();
-		void reset();
-
-	protected:
-		virtual void run();
-
-	private:
-		struct File {
-			int position;
-			QString image_path;
-			QRect rect;
-			QColor color;
-		};
-		QList<File> m_files;
-		QMutex m_file_mutex;
-
-		struct CacheFile {
-			File file;
-			QImage image;
-			bool operator==(const CacheFile& other);
-		};
-		QList<CacheFile> m_cache;
-
-		QImage m_image;
-		QMutex m_image_mutex;
-	} background_loader;
-
-	void BackgroundLoader::create(int position, const QString& image_path, QWidget* widget)
-	{
-		File file = { position, image_path, widget->rect(), widget->palette().color(QPalette::Window) };
-
-		m_file_mutex.lock();
-		m_files.append(file);
-		m_file_mutex.unlock();
-
-		if (!isRunning()) {
-			start();
-		}
-	}
-
-	QPixmap BackgroundLoader::pixmap()
-	{
-		QMutexLocker locker(&m_image_mutex);
-		return QPixmap::fromImage(m_image, Qt::AutoColor | Qt::AvoidDither);
-	}
-
-	void BackgroundLoader::reset()
-	{
-		QMutexLocker locker(&m_image_mutex);
-		m_image = QImage();
-	}
-
-	void BackgroundLoader::run()
-	{
-		m_file_mutex.lock();
-		do {
-			File file = m_files.takeLast();
-			m_files.clear();
-			m_file_mutex.unlock();
-
-			CacheFile cache_file = { file, QImage() };
-			int index = m_cache.indexOf(cache_file);
-			if (index != -1) {
-				cache_file = m_cache.at(index);
-			} else {
-				cache_file.image = Theme::renderBackground(file.image_path, file.position, file.color, file.rect.size());
-				m_cache.prepend(cache_file);
-				while (m_cache.size() > 10) {
-					m_cache.removeLast();
-				}
-			}
-
-			m_image_mutex.lock();
-			m_image = cache_file.image;
-			m_image_mutex.unlock();
-
-			m_file_mutex.lock();
-		} while (!m_files.isEmpty());
-		m_file_mutex.unlock();
-	}
-
-	bool BackgroundLoader::CacheFile::operator==(const CacheFile& other)
-	{
-		return (file.image_path == other.file.image_path)
-			&& (file.color == other.file.color)
-			&& (file.position == other.file.position)
-			&& (file.rect == other.file.rect);
-	}
-}
-
-//-----------------------------------------------------------------------------
-
 Stack::Stack(QWidget* parent) :
 	QWidget(parent),
 	m_symbols_dialog(0),
 	m_current_document(0),
-	m_background_position(0),
-	m_margin(0),
 	m_footer_margin(0),
 	m_header_margin(0),
 	m_footer_visible(0),
@@ -169,6 +65,11 @@ Stack::Stack(QWidget* parent) :
 	m_scenes = new SceneList(this);
 	setScenesVisible(false);
 
+	m_menu = new QMenu(this);
+	m_menu_group = new QActionGroup(this);
+	m_menu_group->setExclusive(true);
+	connect(m_menu_group, SIGNAL(triggered(QAction*)), this, SLOT(actionTriggered(QAction*)));
+
 	m_load_screen = new LoadScreen(this);
 
 	m_find_dialog = new FindDialog(this);
@@ -196,14 +97,21 @@ Stack::Stack(QWidget* parent) :
 	m_resize_timer->setInterval(50);
 	m_resize_timer->setSingleShot(true);
 	connect(m_resize_timer, SIGNAL(timeout()), this, SLOT(updateBackground()));
-	connect(&background_loader, SIGNAL(finished()), this, SLOT(updateBackground()));
+
+	m_theme_renderer = new ThemeRenderer(this);
+	connect(m_theme_renderer, SIGNAL(rendered(QImage,QRect,Theme)), this, SLOT(updateBackground(QImage,QRect)));
+
+	// Always draw background
+	setAttribute(Qt::WA_OpaquePaintEvent);
+	setAutoFillBackground(false);
+	updateBackground();
 }
 
 //-----------------------------------------------------------------------------
 
 Stack::~Stack()
 {
-	background_loader.wait();
+	m_theme_renderer->wait();
 }
 
 //-----------------------------------------------------------------------------
@@ -214,7 +122,6 @@ void Stack::addDocument(Document* document)
 	connect(document, SIGNAL(alert(Alert*)), m_alerts, SLOT(addAlert(Alert*)));
 	connect(document, SIGNAL(alignmentChanged()), this, SIGNAL(updateFormatAlignmentActions()));
 	connect(document, SIGNAL(changedName()), this, SIGNAL(updateFormatActions()));
-	connect(document, SIGNAL(changedName()), this, SLOT(updateMapping()));
 	connect(document, SIGNAL(footerVisible(bool)), this, SLOT(setFooterVisible(bool)));
 	connect(document, SIGNAL(headerVisible(bool)), this, SLOT(setHeaderVisible(bool)));
 	connect(document, SIGNAL(scenesVisible(bool)), this, SLOT(setScenesVisible(bool)));
@@ -226,7 +133,16 @@ void Stack::addDocument(Document* document)
 	m_documents.append(document);
 	m_contents->addWidget(document);
 	m_contents->setCurrentWidget(document);
-	updateMapping();
+
+	QAction* action = new QAction(this);
+	action->setCheckable(true);
+	action->setActionGroup(m_menu_group);
+	m_document_actions.push_back(action);
+	m_menu->addAction(action);
+	updateMenuIndexes();
+
+	document->loadTheme(m_theme, m_foreground);
+	document->text()->setFixedSize(m_foreground_size);
 
 	emit documentAdded(document);
 	emit updateFormatActions();
@@ -236,8 +152,13 @@ void Stack::addDocument(Document* document)
 
 void Stack::moveDocument(int from, int to)
 {
+	QAction* action = m_document_actions.at(from);
+	QAction* before = m_document_actions.at(to);
+	m_menu->removeAction(action);
 	m_documents.move(from, to);
-	updateMapping();
+	m_document_actions.move(from, to);
+	m_menu->insertAction(before, action);
+	updateMenuIndexes();
 }
 
 //-----------------------------------------------------------------------------
@@ -246,9 +167,24 @@ void Stack::removeDocument(int index)
 {
 	Document* document = m_documents.takeAt(index);
 	m_contents->removeWidget(document);
+
+	QAction* action = m_document_actions.takeAt(index);
+	m_menu->removeAction(action);
+	delete action;
+	updateMenuIndexes();
+
 	emit documentRemoved(document);
 	document->close();
-	updateMapping();
+}
+
+//-----------------------------------------------------------------------------
+
+void Stack::updateDocument(int index)
+{
+	Document* document = m_documents.at(index);
+	QAction* action = m_document_actions.at(index);
+	action->setText(document->title() + (document->isModified() ? "*" : ""));
+	action->setToolTip(QDir::toNativeSeparators(document->filename()));
 }
 
 //-----------------------------------------------------------------------------
@@ -258,6 +194,7 @@ void Stack::setCurrentDocument(int index)
 	m_current_document = m_documents[index];
 	m_contents->setCurrentWidget(m_current_document);
 	m_scenes->setDocument(m_current_document);
+	m_document_actions[index]->setChecked(true);
 
 	emit copyAvailable(!m_current_document->text()->textCursor().selectedText().isEmpty());
 	emit redoAvailable(m_current_document->text()->document()->isRedoAvailable());
@@ -281,8 +218,8 @@ void Stack::setMargins(int footer, int header)
 
 void Stack::waitForThemeBackground()
 {
-	if (background_loader.isRunning()) {
-		background_loader.wait();
+	if (m_theme_renderer->isRunning()) {
+		m_theme_renderer->wait();
 		repaint();
 	}
 }
@@ -334,7 +271,7 @@ void Stack::alignRight()
 void Stack::autoCache()
 {
 	foreach (Document* document, m_documents) {
-		if (document->text()->document()->isModified()) {
+		if (document->isModified()) {
 			document->cache();
 		}
 	}
@@ -345,7 +282,7 @@ void Stack::autoCache()
 void Stack::autoSave()
 {
 	foreach (Document* document, m_documents) {
-		if (document->text()->document()->isModified()) {
+		if (document->isModified()) {
 			if (!document->filename().isEmpty()) {
 				document->save();
 			} else {
@@ -383,7 +320,7 @@ void Stack::decreaseIndent()
 	m_current_document->setRichText(true);
 	QTextCursor cursor = m_current_document->text()->textCursor();
 	QTextBlockFormat format = cursor.blockFormat();
-	format.setIndent(qMax(0, format.indent() - 48));
+	format.setIndent(qMax(0, format.indent() - 1));
 	cursor.setBlockFormat(format);
 	emit updateFormatActions();
 }
@@ -416,7 +353,7 @@ void Stack::increaseIndent()
 	m_current_document->setRichText(true);
 	QTextCursor cursor = m_current_document->text()->textCursor();
 	QTextBlockFormat format = cursor.blockFormat();
-	format.setIndent(format.indent() + 48);
+	format.setIndent(format.indent() + 1);
 	cursor.setBlockFormat(format);
 	emit updateFormatActions();
 }
@@ -469,7 +406,6 @@ void Stack::replace()
 void Stack::save()
 {
 	m_current_document->save();
-	updateMapping();
 }
 
 //-----------------------------------------------------------------------------
@@ -611,32 +547,26 @@ void Stack::showSymbols()
 
 void Stack::themeSelected(const Theme& theme)
 {
-	m_background_position = theme.backgroundType();
-	m_background_path = theme.backgroundImage();
-
-	QPalette p = palette();
-	p.setColor(QPalette::Window, theme.backgroundColor().rgb());
-	setPalette(p);
-
-	background_loader.reset();
-	m_background = QPixmap();
-	updateBackground();
-
-	m_margin = theme.foregroundMargin();
-	m_layout->setRowMinimumHeight(0, m_margin);
-	m_layout->setRowMinimumHeight(5, m_margin);
-	m_layout->setColumnMinimumWidth(0, m_margin);
-	m_layout->setColumnMinimumWidth(5, m_margin);
+	m_theme = theme;
 
 	if (m_symbols_dialog) {
-		m_symbols_dialog->setPreviewFont(theme.textFont());
+		m_symbols_dialog->setPreviewFont(m_theme.textFont());
 	}
 
+	int margin = theme.foregroundMargin();
+	m_layout->setRowMinimumHeight(0, margin);
+	m_layout->setRowMinimumHeight(5, margin);
+	m_layout->setColumnMinimumWidth(0, margin);
+	m_layout->setColumnMinimumWidth(5, margin);
+
+	int minimum_size = (margin * 2) + (theme.foregroundPadding() * 2) + 100;
+	window()->setMinimumSize(minimum_size, minimum_size);
+
+	updateBackground();
+
 	foreach (Document* document, m_documents) {
-		document->loadTheme(theme);
+		document->loadTheme(theme, m_foreground);
 	}
-
-	window()->setMinimumWidth((m_margin * 2) + theme.foregroundWidth());
 }
 
 //-----------------------------------------------------------------------------
@@ -730,9 +660,7 @@ void Stack::mouseMoveEvent(QMouseEvent* event)
 void Stack::paintEvent(QPaintEvent* event)
 {
 	QPainter painter(this);
-	if (!m_background.isNull()) {
-		painter.drawPixmap(event->rect(), m_background, event->rect());
-	}
+	painter.drawPixmap(event->rect(), m_background, event->rect());
 	painter.end();
 }
 
@@ -741,7 +669,6 @@ void Stack::paintEvent(QPaintEvent* event)
 void Stack::resizeEvent(QResizeEvent* event)
 {
 	updateMask();
-	m_background = QPixmap();
 	m_resize_timer->start();
 	updateBackground();
 	QWidget::resizeEvent(event);
@@ -749,6 +676,13 @@ void Stack::resizeEvent(QResizeEvent* event)
 
 //-----------------------------------------------------------------------------
 
+void Stack::actionTriggered(QAction* action)
+{
+	emit documentSelected(action->data().toInt());
+}
+
+//-----------------------------------------------------------------------------
+
 void Stack::insertSymbol(const QString& text)
 {
 	m_current_document->text()->insertPlainText(text);
@@ -758,16 +692,67 @@ void Stack::insertSymbol(const QString& text)
 
 void Stack::updateBackground()
 {
-	m_background = background_loader.pixmap();
-	if ((m_background.isNull() || m_background.size() != size()) && isVisible()) {
-		m_background = QPixmap();
-		background_loader.create(m_background_position, m_background_path, this);
-		setAttribute(Qt::WA_NoSystemBackground, false);
-		setAutoFillBackground(true);
-	} else {
-		setAttribute(Qt::WA_NoSystemBackground, true);
-		setAutoFillBackground(false);
+	// Create temporary background
+	QRect foreground = m_theme.foregroundRect(size());
+
+	QImage image(size(), QImage::Format_ARGB32_Premultiplied);
+	image.fill(m_theme.loadColor().rgb());
+	{
+		QPainter painter(&image);
+		QColor color = m_theme.foregroundColor();
+		color.setAlpha(m_theme.foregroundOpacity() * 2.55f);
+		painter.setPen(Qt::NoPen);
+		painter.setBrush(color);
+
+		if (!m_theme.roundCornersEnabled()) {
+			painter.drawRect(foreground);
+		} else {
+			painter.setRenderHint(QPainter::Antialiasing);
+			painter.drawRoundedRect(foreground, m_theme.cornerRadius(), m_theme.cornerRadius());
+		}
 	}
+
+	updateBackground(image, foreground);
+
+	// Create proper background
+	if (!m_resize_timer->isActive()) {
+		m_theme_renderer->create(m_theme, size());
+	}
+}
+
+//-----------------------------------------------------------------------------
+
+void Stack::updateBackground(const QImage& image, const QRect& foreground)
+{
+	// Make sure image is correct size
+	if (image.size() != size()) {
+		return;
+	}
+
+	// Determine text area size
+	int padding = m_theme.foregroundPadding();
+	QRect foreground_rect = foreground.adjusted(padding, padding, -padding, -padding);
+	bool resize = !m_resize_timer->isActive() && (foreground_rect.size() != m_foreground_size);
+	if (resize) {
+		m_foreground_size = foreground_rect.size();
+	}
+
+	// Load background and foreground
+	m_background = QPixmap::fromImage(image, Qt::AutoColor | Qt::AvoidDither);
+	m_foreground = image.copy(foreground_rect);
+
+	// Configure text area
+	foreach (Document* document, m_documents) {
+		QPalette p = document->text()->palette();
+		p.setBrush(QPalette::Base, m_foreground);
+		document->text()->setPalette(p);
+
+		if (resize) {
+			document->text()->setFixedSize(m_foreground_size);
+			document->centerCursor(true);
+		}
+	}
+
 	update();
 }
 
@@ -794,16 +779,10 @@ void Stack::updateMask()
 
 //-----------------------------------------------------------------------------
 
-void Stack::updateMapping()
+void Stack::updateMenuIndexes()
 {
-	QFile file(Document::cachePath() + "/mapping");
-	if (file.open(QFile::WriteOnly | QFile::Text)) {
-		QTextStream stream(&file);
-		stream.setCodec(QTextCodec::codecForName("UTF-8"));
-		stream.setGenerateByteOrderMark(true);
-		foreach (Document* document, m_documents) {
-			stream << QFileInfo(document->cacheFilename()).baseName() << " " << document->filename() << endl;
-		}
+	for (int i = 0; i < m_document_actions.size(); ++i) {
+		m_document_actions[i]->setData(i);
 	}
 }
 
