@@ -439,7 +439,9 @@ void ThemeDialog::createPreview(const QString& id, bool is_default)
 	Theme theme(id, is_default);
 	ThemeDialog dialog(theme);
 	dialog.m_theme_renderer->wait();
-	QCoreApplication::processEvents();
+	while (!dialog.m_load_color.resultCount()) {
+		QCoreApplication::processEvents();
+	}
 	dialog.savePreview();
 }
 
@@ -458,6 +460,14 @@ void ThemeDialog::accept()
 
 //-----------------------------------------------------------------------------
 
+void ThemeDialog::reject()
+{
+	m_theme.forgetChanges();
+	QDialog::reject();
+}
+
+//-----------------------------------------------------------------------------
+
 void ThemeDialog::hideEvent(QHideEvent* event)
 {
 	QSettings().setValue("ThemeDialog/Size", size());
@@ -569,6 +579,7 @@ void ThemeDialog::renderPreview()
 	Theme theme;
 	setValues(theme);
 	theme.setBackgroundImage(m_background_image->image());
+	theme.forgetChanges();
 
 	// Render theme
 	m_theme_renderer->create(theme, QSize(1920, 1080));
